@@ -86,10 +86,15 @@
  * \param name the column name (= aspect name)
  */
 AbstractColumn::AbstractColumn(const QString &name) : AbstractAspect(name),
-	m_abstract_column_private( new Private(this) ) {
+	m_abstract_column_private( new AbstractColumnPrivate(this) ) {
 
 }
 
+AbstractColumn::~AbstractColumn() {
+	aboutToBeDestroyed(this);
+	delete m_abstract_column_private;
+}
+
 /**
  * \fn bool AbstractColumn::isReadOnly() const
  * \brief Return whether the object is read-only
