@@ -48,6 +48,10 @@ class Matrix : public AbstractDataSource {
 		virtual QMenu* createContextMenu();
 		virtual QWidget* view() const;
 
+		virtual void exportView() const;
+		virtual void printView();
+		virtual void printPreview() const;
+
 		BASIC_D_ACCESSOR_DECL(int, rowCount, RowCount)
 		BASIC_D_ACCESSOR_DECL(int, columnCount, ColumnCount)
 		BASIC_D_ACCESSOR_DECL(double, xStart, XStart)
@@ -145,6 +149,7 @@ class Matrix : public AbstractDataSource {
 		friend class MatrixSetPrecisionCmd;
 		void numericFormatChanged(char);
 		void precisionChanged(int);
+		void headerFormatChanged(Matrix::HeaderFormat);
 
 	private:
 		void init();
