@@ -3,10 +3,9 @@
     Project              : LabPlot
     Description          : Aspect providing a spreadsheet table with column logic
     --------------------------------------------------------------------
-    Copyright            : (C) 2012-2013 Alexander Semke (alexander.semke@web.de)
+    Copyright            : (C) 2012-2015 Alexander Semke (alexander.semke@web.de)
     Copyright            : (C) 2006-2008 Tilman Benkert (thzs@gmx.net)
     Copyright            : (C) 2006-2009 Knut Franke (knut.franke@gmx.de)
-    Copyright            : (C) 2006-2007 Ion Vasilief (ion_vasilief@yahoo.fr)
 
  ***************************************************************************/
 
@@ -32,21 +31,16 @@
 #include "backend/core/AspectPrivate.h"
 #include "backend/core/AbstractAspect.h"
 #include "commonfrontend/spreadsheet/SpreadsheetView.h"
-#include "backend/lib/commandtemplates.h"
-#include "backend/lib/macros.h"
+#include "kdefrontend/spreadsheet/ExportSpreadsheetDialog.h"
+
+#include <QPrinter>
+#include <QPrintDialog>
+#include <QPrintPreviewDialog>
 
-#ifndef ACTIVATE_SCIDAVIS_SPECIFIC_CODE
 #include <KIcon>
-#include <KConfig>
 #include <KConfigGroup>
 #include <KLocale>
-#endif
 
-#include <QApplication>
-#include <QDateTime>
-#include <QMenu>
-#include <QPrinter>
-#include <QDebug>
 /*!
   \class Spreadsheet
   \brief Aspect providing a spreadsheet table with column logic.
@@ -68,25 +62,22 @@
   \ingroup backend
 */
 
-Spreadsheet::Spreadsheet(AbstractScriptingEngine *engine, const QString& name)
+Spreadsheet::Spreadsheet(AbstractScriptingEngine* engine, const QString& name, bool loading)
   : AbstractDataSource(engine, name){
 
+	if (!loading)
+		init();
 }
 
 /*!
 	initializes the spreadsheet with the default number of columns and rows
 */
-void Spreadsheet::initDefault() {
+void Spreadsheet::init() {
 	int columns, rows;
-#ifdef ACTIVATE_SCIDAVIS_SPECIFIC_CODE
-	columns = 2;
-	rows = 100;
-#else
 	KConfig config;
 	KConfigGroup group = config.group( "Spreadsheet" );
 	columns = group.readEntry("ColumnCount", 2);
 	rows = group.readEntry("RowCount", 100);
-#endif
 
 	for(int i=0; i<columns; i++) {
 		Column* new_col = new Column(QString::number(i+1), AbstractColumn::Numeric);
@@ -100,20 +91,51 @@ void Spreadsheet::initDefault() {
   This method may be called multiple times during the life time of an Aspect, or it might not get
   called at all. Aspects must not depend on the existence of a view for their operation.
 */
-QWidget *Spreadsheet::view() const
-{
+QWidget *Spreadsheet::view() const {
 	if (!m_view) {
 		m_view = new SpreadsheetView(const_cast<Spreadsheet*>(this));
-#ifndef ACTIVATE_SCIDAVIS_SPECIFIC_CODE
 		KConfig config;
 		KConfigGroup group = config.group( "Spreadsheet" );
 		reinterpret_cast<SpreadsheetView*>(m_view)->showComments(group.readEntry("ShowComments", false));
-#endif
 	}
 
 	return m_view;
 }
 
+void Spreadsheet::exportView() const {
+	ExportSpreadsheetDialog* dlg = new ExportSpreadsheetDialog(view());
+	dlg->setFileName(name());
+	if (dlg->exec()==QDialog::Accepted){
+		const QString path = dlg->path();
+		const bool exportHeader = dlg->exportHeader();
+		const QString separator = dlg->separator();
+
+		const SpreadsheetView* view = reinterpret_cast<const SpreadsheetView*>(m_view);
+		WAIT_CURSOR;
+		view->exportToFile(path, exportHeader, separator);
+		RESET_CURSOR;
+	}
+	delete dlg;
+}
+
+void Spreadsheet::printView() {
+	QPrinter printer;
+	QPrintDialog* dlg = new QPrintDialog(&printer, view());
+	dlg->setWindowTitle(i18n("Print Spreadsheet"));
+	if (dlg->exec() == QDialog::Accepted) {
+		const SpreadsheetView* view = reinterpret_cast<const SpreadsheetView*>(m_view);
+		view->print(&printer);
+	}
+	delete dlg;
+}
+
+void Spreadsheet::printPreview() const {
+	const SpreadsheetView* view = reinterpret_cast<const SpreadsheetView*>(m_view);
+	QPrintPreviewDialog* dlg = new QPrintPreviewDialog(m_view);
+	connect(dlg, SIGNAL(paintRequested(QPrinter*)), view, SLOT(print(QPrinter*)));
+	dlg->exec();
+}
+
 /*!
   Returns the total number of rows in the spreadsheet.
  */
@@ -614,7 +636,7 @@ void Spreadsheet::sortColumns(Column *leading, QList<Column*> cols, bool ascendi
   Returns an icon to be used for decorating my views.
   */
 QIcon Spreadsheet::icon() const {
-	return KIcon("table"); //or KIcon("x-office-spreadsheet")
+	return KIcon("labplot-spreadsheet");
 }
 
 /*!
@@ -712,7 +734,7 @@ bool Spreadsheet::load(XmlStreamReader * reader)
 				}
 				else if(reader->name() == "column")
 				{
-					Column* column = new Column("", AbstractColumn::Text);
+					Column* column = new Column("");
 					if (!column->load(reader))
 					{
                         delete column;
