@@ -44,7 +44,7 @@ class Axis: public WorksheetElement {
 	public:
 		enum AxisOrientation {AxisHorizontal, AxisVertical};
 		enum AxisPosition {AxisTop, AxisBottom, AxisLeft, AxisRight, AxisCentered, AxisCustom};
-		enum LabelsFormat {FormatDecimal, FormatScientificE, FormatPowers10, FormatPowers2, FormatPowersE};
+		enum LabelsFormat {FormatDecimal, FormatScientificE, FormatPowers10, FormatPowers2, FormatPowersE, FormatMultipliesPi};
 		enum TicksFlags {
 			noTicks = 0x00,
 			ticksIn = 0x01,
@@ -64,7 +64,9 @@ class Axis: public WorksheetElement {
 
 		virtual QIcon icon() const;
 		virtual QMenu* createContextMenu();
-		virtual QGraphicsItem *graphicsItem() const;
+
+		virtual QGraphicsItem* graphicsItem() const;
+		virtual void setZValue(qreal);
 
 		virtual void save(QXmlStreamWriter *) const;
 		virtual bool load(XmlStreamReader *);
@@ -277,7 +279,7 @@ class Axis: public WorksheetElement {
 		void minorGridPenChanged(QPen);
 		void minorGridOpacityChanged(qreal);
 
-		void visibleChanged(bool);
+		void visibilityChanged(bool);
 };
 
 Q_DECLARE_OPERATORS_FOR_FLAGS(Axis::TicksDirection)
