@@ -34,6 +34,7 @@
 #include "XYFitCurve.h"
 #include "backend/core/Project.h"
 #include "backend/worksheet/plots/cartesian/CartesianPlotLegend.h"
+#include "backend/worksheet/plots/cartesian/CustomPoint.h"
 #include "backend/worksheet/plots/PlotArea.h"
 #include "backend/worksheet/plots/AbstractPlotPrivate.h"
 #include "backend/worksheet/Worksheet.h"
@@ -43,7 +44,6 @@
 #include "backend/lib/commandtemplates.h"
 #include <math.h>
 
-#include <QDebug>
 #include <QMenu>
 #include <QToolBar>
 #include <QPainter>
@@ -75,6 +75,7 @@ CartesianPlot::CartesianPlot(const QString &name, CartesianPlotPrivate *dd):Abst
 CartesianPlot::~CartesianPlot(){
 	delete m_coordinateSystem;
 	delete addNewMenu;
+	delete zoomMenu;
 
 	//don't need to delete objects added with addChild()
 
@@ -341,12 +342,13 @@ void CartesianPlot::initDefault(Type type){
 
 void CartesianPlot::initActions(){
 	//"add new" actions
-	addCurveAction = new KAction(KIcon("xy-curve"), i18n("xy-curve"), this);
-	addEquationCurveAction = new KAction(KIcon("xy-equation-curve"), i18n("xy-curve from a mathematical equation"), this);
-	addFitCurveAction = new KAction(KIcon("xy-fit-curve"), i18n("xy-curve from a fit to data"), this);
+	addCurveAction = new KAction(KIcon("labplot-xy-curve"), i18n("xy-curve"), this);
+	addEquationCurveAction = new KAction(KIcon("labplot-xy-equation-curve"), i18n("xy-curve from a mathematical equation"), this);
+	addFitCurveAction = new KAction(KIcon("labplot-xy-fit-curve"), i18n("xy-curve from a fit to data"), this);
 	addLegendAction = new KAction(KIcon("text-field"), i18n("legend"), this);
-	addHorizontalAxisAction = new KAction(KIcon("axis-horizontal"), i18n("horizontal axis"), this);
-	addVerticalAxisAction = new KAction(KIcon("axis-vertical"), i18n("vertical axis"), this);
+	addHorizontalAxisAction = new KAction(KIcon("labplot-axis-horizontal"), i18n("horizontal axis"), this);
+	addVerticalAxisAction = new KAction(KIcon("labplot-axis-vertical"), i18n("vertical axis"), this);
+	addCustomPointAction = new KAction(KIcon("draw-cross"), i18n("custom point"), this);
 
 	connect(addCurveAction, SIGNAL(triggered()), SLOT(addCurve()));
 	connect(addEquationCurveAction, SIGNAL(triggered()), SLOT(addEquationCurve()));
@@ -354,21 +356,22 @@ void CartesianPlot::initActions(){
 	connect(addLegendAction, SIGNAL(triggered()), SLOT(addLegend()));
 	connect(addHorizontalAxisAction, SIGNAL(triggered()), SLOT(addHorizontalAxis()));
 	connect(addVerticalAxisAction, SIGNAL(triggered()), SLOT(addVerticalAxis()));
+	connect(addCustomPointAction, SIGNAL(triggered()), SLOT(addCustomPoint()));
 
 	//zoom/navigate actions
-	scaleAutoAction = new KAction(KIcon("auto-scale-all"), i18n("auto scale"), this);
-	scaleAutoXAction = new KAction(KIcon("auto-scale-x"), i18n("auto scale X"), this);
-	scaleAutoYAction = new KAction(KIcon("auto-scale-y"), i18n("auto scale Y"), this);
+	scaleAutoAction = new KAction(KIcon("labplot-auto-scale-all"), i18n("auto scale"), this);
+	scaleAutoXAction = new KAction(KIcon("labplot-auto-scale-x"), i18n("auto scale X"), this);
+	scaleAutoYAction = new KAction(KIcon("labplot-auto-scale-y"), i18n("auto scale Y"), this);
 	zoomInAction = new KAction(KIcon("zoom-in"), i18n("zoom in"), this);
 	zoomOutAction = new KAction(KIcon("zoom-out"), i18n("zoom out"), this);
-	zoomInXAction = new KAction(KIcon("zoom-in-x"), i18n("zoom in X"), this);
-	zoomOutXAction = new KAction(KIcon("zoom-out-x"), i18n("zoom out X"), this);
-	zoomInYAction = new KAction(KIcon("zoom-in-y"), i18n("zoom in Y"), this);
-	zoomOutYAction = new KAction(KIcon("zoom-out-y"), i18n("zoom out Y"), this);
-    shiftLeftXAction = new KAction(KIcon("shift-left-x"), i18n("shift left X"), this);
-	shiftRightXAction = new KAction(KIcon("shift-right-x"), i18n("shift right X"), this);
-	shiftUpYAction = new KAction(KIcon("shift-up-y"), i18n("shift up Y"), this);
-	shiftDownYAction = new KAction(KIcon("shift-down-y"), i18n("shift down Y"), this);
+	zoomInXAction = new KAction(KIcon("labplot-zoom-in-x"), i18n("zoom in X"), this);
+	zoomOutXAction = new KAction(KIcon("labplot-zoom-out-x"), i18n("zoom out X"), this);
+	zoomInYAction = new KAction(KIcon("labplot-zoom-in-y"), i18n("zoom in Y"), this);
+	zoomOutYAction = new KAction(KIcon("labplot-zoom-out-y"), i18n("zoom out Y"), this);
+    shiftLeftXAction = new KAction(KIcon("labplot-shift-left-x"), i18n("shift left X"), this);
+	shiftRightXAction = new KAction(KIcon("labplot-shift-right-x"), i18n("shift right X"), this);
+	shiftUpYAction = new KAction(KIcon("labplot-shift-up-y"), i18n("shift up Y"), this);
+	shiftDownYAction = new KAction(KIcon("labplot-shift-down-y"), i18n("shift down Y"), this);
 
 	connect(scaleAutoAction, SIGNAL(triggered()), SLOT(scaleAuto()));
 	connect(scaleAutoXAction, SIGNAL(triggered()), SLOT(scaleAutoX()));
@@ -399,6 +402,8 @@ void CartesianPlot::initMenus(){
 	addNewMenu->addSeparator();
 	addNewMenu->addAction(addHorizontalAxisAction);
 	addNewMenu->addAction(addVerticalAxisAction);
+	addNewMenu->addSeparator();
+	addNewMenu->addAction(addCustomPointAction);
 
 	zoomMenu = new QMenu(i18n("Zoom"));
 	zoomMenu->addAction(scaleAutoAction);
@@ -423,12 +428,7 @@ void CartesianPlot::initMenus(){
 
 QMenu* CartesianPlot::createContextMenu(){
 	QMenu* menu = WorksheetElement::createContextMenu();
-
-#ifdef ACTIVATE_SCIDAVIS_SPECIFIC_CODE
-	QAction* firstAction = menu->actions().first();
-#else
 	QAction* firstAction = menu->actions().at(1);
-#endif
 
 	visibilityAction->setChecked(isVisible());
 	menu->insertAction(firstAction, visibilityAction);
@@ -444,13 +444,23 @@ QMenu* CartesianPlot::createContextMenu(){
 	Returns an icon to be used in the project explorer.
 */
 QIcon CartesianPlot::icon() const{
-	QIcon ico;
-#ifdef ACTIVATE_SCIDAVIS_SPECIFIC_CODE
-	ico.addPixmap(QPixmap(":/graph.xpm"));
-#else
-	ico = KIcon("office-chart-line");
-#endif
-	return ico;
+	return KIcon("office-chart-line");
+}
+
+void CartesianPlot::navigate(CartesianPlot::NavigationOperation op) {
+	if (op==ScaleAuto) scaleAuto();
+	else if (op==ScaleAutoX) scaleAutoX();
+	else if (op==ScaleAutoY) scaleAutoY();
+	else if (op==ZoomIn) zoomIn();
+	else if (op==ZoomOut) zoomOut();
+	else if (op==ZoomInX) zoomInX();
+	else if (op==ZoomOutX) zoomOutX();
+	else if (op==ZoomInY) zoomInY();
+	else if (op==ZoomOutY) zoomOutY();
+	else if (op==ShiftLeftX) shiftLeftX();
+	else if (op==ShiftRightX) shiftRightX();
+	else if (op==ShiftUpY) shiftUpY();
+	else if (op==ShiftDownY) shiftDownY();
 }
 
 //##############################################################################
@@ -503,16 +513,47 @@ void CartesianPlot::setRect(const QRectF& rect){
 		exec(new CartesianPlotSetRectCmd(d, rect, i18n("%1: set geometry rect")));
 }
 
-//TODO: provide an undo-aware version
-// STD_SETTER_CMD_IMPL_F(CartesianPlot, SetAutoScaleX, bool, autoScaleX, retransformScales)
+class CartesianPlotSetAutoScaleXCmd : public QUndoCommand {
+	public:
+		CartesianPlotSetAutoScaleXCmd(CartesianPlotPrivate* private_obj, bool autoScale) {
+			m_private = private_obj;
+			m_autoScale = autoScale;
+			setText(i18n("%1: change x-range auto scaling", m_private->name()));
+		};
+
+		virtual void redo() {
+			m_autoScaleOld = m_private->autoScaleX;
+			if (m_autoScale) {
+				m_minOld = m_private->xMin;
+				m_maxOld = m_private->xMax;
+				m_private->q->scaleAutoX();
+			}
+			m_private->autoScaleX = m_autoScale;
+			emit m_private->q->xAutoScaleChanged(m_autoScale);
+		};
+
+		virtual void undo() {
+			if (!m_autoScaleOld) {
+				m_private->xMin = m_minOld;
+				m_private->xMax = m_maxOld;
+				m_private->retransformScales();
+			}
+			m_private->autoScaleX = m_autoScaleOld;
+			emit m_private->q->xAutoScaleChanged(m_autoScaleOld);
+		}
+
+	private:
+		CartesianPlotPrivate* m_private;
+		bool m_autoScale;
+		bool m_autoScaleOld;
+		float m_minOld;
+		float m_maxOld;
+};
+
 void CartesianPlot::setAutoScaleX(bool autoScaleX){
 	Q_D(CartesianPlot);
-	if (autoScaleX != d->autoScaleX){
-// 		exec(new CartesianPlotSetAutoScaleXCmd(d, autoScaleX, i18n("%1: change auto scale x")));
-		d->autoScaleX = autoScaleX;
-		if (autoScaleX)
-			this->scaleAutoX();
-	}
+	if (autoScaleX != d->autoScaleX)
+		exec(new CartesianPlotSetAutoScaleXCmd(d, autoScaleX));
 }
 
 STD_SETTER_CMD_IMPL_F_S(CartesianPlot, SetXMin, float, xMin, retransformScales)
@@ -543,17 +584,47 @@ void CartesianPlot::setXScaleBreakings(const ScaleBreakings& breakings) {
 	exec(new CartesianPlotSetXScaleBreakingsCmd(d, breakings, i18n("%1: set x-scale breakings")));
 }
 
+class CartesianPlotSetAutoScaleYCmd : public QUndoCommand {
+	public:
+		CartesianPlotSetAutoScaleYCmd(CartesianPlotPrivate* private_obj, bool autoScale) {
+			m_private = private_obj;
+			m_autoScale = autoScale;
+			setText(i18n("%1: change y-range auto scaling", m_private->name()));
+		};
+
+		virtual void redo() {
+			m_autoScaleOld = m_private->autoScaleY;
+			if (m_autoScale) {
+				m_minOld = m_private->yMin;
+				m_maxOld = m_private->yMax;
+				m_private->q->scaleAutoY();
+			}
+			m_private->autoScaleY = m_autoScale;
+			emit m_private->q->yAutoScaleChanged(m_autoScale);
+		};
+
+		virtual void undo() {
+			if (!m_autoScaleOld) {
+				m_private->yMin = m_minOld;
+				m_private->yMax = m_maxOld;
+				m_private->retransformScales();
+			}
+			m_private->autoScaleY = m_autoScaleOld;
+			emit m_private->q->yAutoScaleChanged(m_autoScaleOld);
+		}
+
+	private:
+		CartesianPlotPrivate* m_private;
+		bool m_autoScale;
+		bool m_autoScaleOld;
+		float m_minOld;
+		float m_maxOld;
+};
 
-//TODO: provide an undo-aware version
-// STD_SETTER_CMD_IMPL_F(CartesianPlot, SetAutoScaleY, bool, autoScaleY, retransformScales)
 void CartesianPlot::setAutoScaleY(bool autoScaleY){
 	Q_D(CartesianPlot);
-	if (autoScaleY != d->autoScaleY){
-// 		exec(new CartesianPlotSetAutoScaleYCmd(d, autoScaleY, i18n("%1: change auto scale y")));
-		d->autoScaleY = autoScaleY;
-		if (autoScaleY)
-			this->scaleAutoY();
-	}
+	if (autoScaleY != d->autoScaleY)
+		exec(new CartesianPlotSetAutoScaleYCmd(d, autoScaleY));
 }
 
 STD_SETTER_CMD_IMPL_F_S(CartesianPlot, SetYMin, float, yMin, retransformScales);
@@ -640,6 +711,11 @@ void CartesianPlot::addLegend(){
 	addLegendAction->setEnabled(false);
 }
 
+void CartesianPlot::addCustomPoint() {
+	CustomPoint* point= new CustomPoint(this, "custom point");
+	this->addChild(point);
+}
+
 void CartesianPlot::childAdded(const AbstractAspect* child) {
 	Q_D(CartesianPlot);
 	const XYCurve* curve = qobject_cast<const XYCurve*>(child);
@@ -647,14 +723,14 @@ void CartesianPlot::childAdded(const AbstractAspect* child) {
 		connect(curve, SIGNAL(dataChanged()), this, SLOT(dataChanged()));
 		connect(curve, SIGNAL(xDataChanged()), this, SLOT(xDataChanged()));
 		connect(curve, SIGNAL(yDataChanged()), this, SLOT(yDataChanged()));
-		connect(curve, SIGNAL(visibilityChanged()), this, SLOT(curveVisibilityChanged()));
+		connect(curve, SIGNAL(visibilityChanged(bool)), this, SLOT(curveVisibilityChanged()));
 
 		//update the legend on changes of the name, line and symbol styles
 		connect(curve, SIGNAL(aspectDescriptionChanged(const AbstractAspect*)), this, SLOT(updateLegend()));
 		connect(curve, SIGNAL(lineTypeChanged(XYCurve::LineType)), this, SLOT(updateLegend()));
 		connect(curve, SIGNAL(linePenChanged(QPen)), this, SLOT(updateLegend()));
 		connect(curve, SIGNAL(lineOpacityChanged(qreal)), this, SLOT(updateLegend()));
-		connect(curve, SIGNAL(symbolsStyleChanged(XYCurve::SymbolsStyle)), this, SLOT(updateLegend()));
+		connect(curve, SIGNAL(symbolsStyleChanged(Symbol::Style)), this, SLOT(updateLegend()));
 		connect(curve, SIGNAL(symbolsSizeChanged(qreal)), this, SLOT(updateLegend()));
 		connect(curve, SIGNAL(symbolsRotationAngleChanged(qreal)), this, SLOT(updateLegend()));
 		connect(curve, SIGNAL(symbolsOpacityChanged(qreal)), this, SLOT(updateLegend()));
@@ -1119,6 +1195,7 @@ void CartesianPlot::visibilityChanged(){
 //#####################################################################
 CartesianPlotPrivate::CartesianPlotPrivate(CartesianPlot *owner)
 	: AbstractPlotPrivate(owner), q(owner), curvesXMinMaxIsDirty(false), curvesYMinMaxIsDirty(false),
+	curvesXMin(INFINITY), curvesXMax(-INFINITY), curvesYMin(INFINITY), curvesYMax(-INFINITY),
 	suppressRetransform(false), m_printing(false), m_selectionBandIsShown(false), cSystem(0),
 	mouseMode(CartesianPlot::SelectionMode){
 	setData(0, WorksheetElement::NameCartesianPlot);
@@ -1429,7 +1506,7 @@ void CartesianPlotPrivate::mouseReleaseEvent(QGraphicsSceneMouseEvent* event) {
 		QGraphicsItem::mouseReleaseEvent(event);
 	} else if (mouseMode == CartesianPlot::ZoomSelectionMode || mouseMode == CartesianPlot::ZoomXSelectionMode || mouseMode == CartesianPlot::ZoomYSelectionMode) {
 		//don't zoom if very small region was selected, avoid occasional/unwanted zooming
-		if ( abs(m_selectionEnd.x()-m_selectionStart.x())<20 || abs(m_selectionEnd.y()-m_selectionStart.y())<20 ) {
+		if ( qAbs(m_selectionEnd.x()-m_selectionStart.x())<20 || qAbs(m_selectionEnd.y()-m_selectionStart.y())<20 ) {
 			m_selectionBandIsShown = false;
 			return;
 		}
@@ -1793,6 +1870,14 @@ bool CartesianPlot::load(XmlStreamReader* reader){
                 addChild(m_legend);
 				addLegendAction->setEnabled(false);	//only one legend is allowed -> disable the action
             }
+		}else if(reader->name() == "customPoint"){
+			CustomPoint* point = new CustomPoint(this, "");
+			if (!point->load(reader)){
+				delete point;
+				return false;
+			}else{
+				addChild(point);
+			}
         }else{ // unknown element
             reader->raiseWarning(i18n("unknown cartesianPlot element '%1'", reader->name().toString()));
             if (!reader->skipToEndElement()) return false;
