@@ -29,27 +29,36 @@
 #include "kdefrontend/GuiObserver.h"
 #include "backend/core/AspectTreeModel.h"
 #include "backend/core/AbstractAspect.h"
+#include "backend/matrix/Matrix.h"
 #include "backend/spreadsheet/Spreadsheet.h"
 #include "backend/worksheet/Worksheet.h"
 #include "backend/worksheet/plots/cartesian/CartesianPlot.h"
 #include "backend/worksheet/plots/cartesian/CartesianPlotLegend.h"
 #include "backend/worksheet/plots/cartesian/XYCurve.h"
 #include "backend/worksheet/plots/cartesian/Axis.h"
+#include "backend/worksheet/plots/cartesian/CustomPoint.h"
 #include "backend/worksheet/TextLabel.h"
 #include "backend/core/Project.h"
+#include "backend/datapicker/Datapicker.h"
+#include "backend/datapicker/DatapickerImage.h"
+#include "backend/datapicker/DatapickerCurve.h"
 #include "commonfrontend/ProjectExplorer.h"
 #include "kdefrontend/MainWin.h"
 #include "kdefrontend/dockwidgets/AxisDock.h"
 #include "kdefrontend/dockwidgets/CartesianPlotDock.h"
 #include "kdefrontend/dockwidgets/CartesianPlotLegendDock.h"
 #include "kdefrontend/dockwidgets/ColumnDock.h"
+#include "kdefrontend/dockwidgets/MatrixDock.h"
 #include "kdefrontend/dockwidgets/ProjectDock.h"
 #include "kdefrontend/dockwidgets/SpreadsheetDock.h"
 #include "kdefrontend/dockwidgets/XYCurveDock.h"
 #include "kdefrontend/dockwidgets/XYEquationCurveDock.h"
 #include "kdefrontend/dockwidgets/XYFitCurveDock.h"
+#include "kdefrontend/dockwidgets/CustomPointDock.h"
 #include "kdefrontend/dockwidgets/WorksheetDock.h"
 #include "kdefrontend/widgets/LabelWidget.h"
+#include "kdefrontend/widgets/DatapickerImageWidget.h"
+#include "kdefrontend/widgets/DatapickerCurveWidget.h"
 
 #include <kstatusbar.h>
 
@@ -141,6 +150,22 @@ GuiObserver::GuiObserver(MainWin* mainWin) : m_lastCartesianPlot(0){
 	mainWindow->columnDock->setColumns(list);
 
 	mainWindow->stackedWidget->setCurrentWidget(mainWindow->columnDock);
+  }else if (className=="Matrix"){
+	mainWindow->m_propertiesDock->setWindowTitle(i18n("Matrix properties"));
+
+	if (!mainWindow->matrixDock){
+	  mainWindow->matrixDock = new MatrixDock(mainWindow->stackedWidget);
+	  connect(mainWindow->matrixDock, SIGNAL(info(QString)), mainWindow->statusBar(), SLOT(showMessage(QString)));
+	  mainWindow->stackedWidget->addWidget(mainWindow->matrixDock);
+	}
+
+	QList<Matrix*> list;
+	foreach(aspect, selectedAspects){
+	  list<<qobject_cast<Matrix*>(aspect);
+	}
+	mainWindow->matrixDock->setMatrices(list);
+
+	mainWindow->stackedWidget->setCurrentWidget(mainWindow->matrixDock);
   }else if (className=="Worksheet"){
 	mainWindow->m_propertiesDock->setWindowTitle(i18n("Worksheet properties"));
 
@@ -271,6 +296,51 @@ GuiObserver::GuiObserver(MainWin* mainWin) : m_lastCartesianPlot(0){
 	mainWindow->textLabelDock->setLabels(list);
 
 	mainWindow->stackedWidget->setCurrentWidget(mainWindow->textLabelDock);
+  }else if (className=="CustomPoint"){
+	mainWindow->m_propertiesDock->setWindowTitle(i18n("Custom point properties"));
+
+	if (!mainWindow->customPointDock){
+	  mainWindow->customPointDock = new CustomPointDock(mainWindow->stackedWidget);
+	  mainWindow->stackedWidget->addWidget(mainWindow->customPointDock);
+	}
+
+	QList<CustomPoint*> list;
+	foreach(aspect, selectedAspects){
+	  list<<qobject_cast<CustomPoint*>(aspect);
+	}
+	mainWindow->customPointDock->setPoints(list);
+
+	mainWindow->stackedWidget->setCurrentWidget(mainWindow->customPointDock);
+  }else if (className=="DatapickerCurve"){
+      mainWindow->m_propertiesDock->setWindowTitle(i18n("DatapickerCurve properties"));
+
+      if (!mainWindow->datapickerCurveDock){
+        mainWindow->datapickerCurveDock = new DatapickerCurveWidget(mainWindow->stackedWidget);
+        mainWindow->stackedWidget->addWidget(mainWindow->datapickerCurveDock);
+      }
+
+      QList<DatapickerCurve*> list;
+      foreach(aspect, selectedAspects){
+        list<<qobject_cast<DatapickerCurve*>(aspect);
+      }
+      mainWindow->datapickerCurveDock->setCurves(list);
+
+      mainWindow->stackedWidget->setCurrentWidget(mainWindow->datapickerCurveDock);
+  }else if (className=="Datapicker"){
+      mainWindow->m_propertiesDock->setWindowTitle(i18n("Datapicker properties"));
+
+      if (!mainWindow->datapickerImageDock){
+        mainWindow->datapickerImageDock = new DatapickerImageWidget(mainWindow->stackedWidget);
+        mainWindow->stackedWidget->addWidget(mainWindow->datapickerImageDock);
+      }
+
+      QList<DatapickerImage*> list;
+      foreach(aspect, selectedAspects){
+        list<<qobject_cast<Datapicker*>(aspect)->image();
+      }
+      mainWindow->datapickerImageDock->setImages(list);
+
+      mainWindow->stackedWidget->setCurrentWidget(mainWindow->datapickerImageDock);
   }else if (className=="Project"){
 	mainWindow->m_propertiesDock->setWindowTitle(i18n("Project properties"));
 
