@@ -3,7 +3,7 @@
     Project              : LabPlot
     Description          : widget for cartesian plot properties
     --------------------------------------------------------------------
-    Copyright            : (C) 2011-2014 by Alexander Semke (alexander.semke@web.de)
+    Copyright            : (C) 2011-2016 by Alexander Semke (alexander.semke@web.de)
     Copyright            : (C) 2012-2013 by Stefan Gerlach (stefan.gerlach@uni-konstanz.de)
 
  ***************************************************************************/
@@ -28,7 +28,6 @@
  ***************************************************************************/
 
 #include "CartesianPlotDock.h"
-#include "backend/worksheet/Worksheet.h"
 #include "backend/worksheet/plots/PlotArea.h"
 #include "kdefrontend/widgets/LabelWidget.h"
 #include "kdefrontend/GuiTools.h"
@@ -38,6 +37,7 @@
 #include <QTimer>
 #include <QDir>
 #include <QFileDialog>
+#include <QImageReader>
 #include <KUrlCompletion>
 
 #include <math.h>
@@ -50,7 +50,10 @@
 */
 
 CartesianPlotDock::CartesianPlotDock(QWidget *parent): QWidget(parent),
-	m_initializing(false){
+	m_plot(0),
+	labelWidget(0),
+	m_initializing(false),
+	m_completion(new KUrlCompletion()) {
 
 	ui.setupUi(this);
 
@@ -67,8 +70,7 @@ CartesianPlotDock::CartesianPlotDock(QWidget *parent): QWidget(parent),
 	ui.kleBackgroundFileName->setClearButtonShown(true);
 	ui.bOpen->setIcon( KIcon("document-open") );
 
-	KUrlCompletion *comp = new KUrlCompletion();
-	ui.kleBackgroundFileName->setCompletionObject(comp);
+	ui.kleBackgroundFileName->setCompletionObject(m_completion);
 
 	//"Title"-tab
 	QHBoxLayout* hboxLayout = new QHBoxLayout(ui.tabTitle);
@@ -98,7 +100,7 @@ CartesianPlotDock::CartesianPlotDock(QWidget *parent): QWidget(parent),
 	//General
 	connect( ui.leName, SIGNAL(returnPressed()), this, SLOT(nameChanged()) );
 	connect( ui.leComment, SIGNAL(returnPressed()), this, SLOT(commentChanged()) );
-	connect( ui.chkVisible, SIGNAL(stateChanged(int)), this, SLOT(visibilityChanged(int)) );
+	connect( ui.chkVisible, SIGNAL(clicked(bool)), this, SLOT(visibilityChanged(bool)) );
 	connect( ui.sbLeft, SIGNAL(valueChanged(double)), this, SLOT(geometryChanged()) );
 	connect( ui.sbTop, SIGNAL(valueChanged(double)), this, SLOT(geometryChanged()) );
 	connect( ui.sbWidth, SIGNAL(valueChanged(double)), this, SLOT(geometryChanged()) );
@@ -158,7 +160,7 @@ CartesianPlotDock::CartesianPlotDock(QWidget *parent): QWidget(parent),
 	ui.verticalLayout->addWidget(templateHandler);
 	templateHandler->show();
 	connect(templateHandler, SIGNAL(loadConfigRequested(KConfig&)), this, SLOT(loadConfigFromTemplate(KConfig&)));
-	connect(templateHandler, SIGNAL(saveConfigRequested(KConfig&)), this, SLOT(saveConfig(KConfig&)));
+	connect(templateHandler, SIGNAL(saveConfigRequested(KConfig&)), this, SLOT(saveConfigAsTemplate(KConfig&)));
 	connect(templateHandler, SIGNAL(info(QString)), this, SIGNAL(info(QString)));
 
 	init();
@@ -167,6 +169,10 @@ CartesianPlotDock::CartesianPlotDock(QWidget *parent): QWidget(parent),
 	ui.tabWidget->removeTab(2);
 }
 
+CartesianPlotDock::~CartesianPlotDock() {
+	delete m_completion;
+}
+
 void CartesianPlotDock::init(){
 	this->retranslateUi();
 
@@ -227,7 +233,7 @@ void CartesianPlotDock::setPlots(QList<CartesianPlot*> list){
 
 	labelWidget->setLabels(labels);
 
-	//if there is more then one curve in the list, disable the tab "general"
+	//if there is more then one plot in the list, disable the name and comment fields in the tab "general"
 	if (list.size()==1){
 		ui.lName->setEnabled(true);
 		ui.leName->setEnabled(true);
@@ -246,7 +252,7 @@ void CartesianPlotDock::setPlots(QList<CartesianPlot*> list){
 		ui.leComment->setText("");
 	}
 
-	//show the properties of the first curve
+	//show the properties of the first plot
   	this->load();
 
 	//update active widgets
@@ -268,9 +274,11 @@ void CartesianPlotDock::setPlots(QList<CartesianPlot*> list){
 	//SIGNALs/SLOTs
 	connect( m_plot, SIGNAL(aspectDescriptionChanged(const AbstractAspect*)), this, SLOT(plotDescriptionChanged(const AbstractAspect*)) );
 	connect( m_plot, SIGNAL(rectChanged(QRectF&)), this, SLOT(plotRectChanged(QRectF&)) );
+	connect( m_plot, SIGNAL(xAutoScaleChanged(bool)), this, SLOT(plotXAutoScaleChanged(bool)) );
 	connect( m_plot, SIGNAL(xMinChanged(float)), this, SLOT(plotXMinChanged(float)) );
 	connect( m_plot, SIGNAL(xMaxChanged(float)), this, SLOT(plotXMaxChanged(float)) );
 	connect( m_plot, SIGNAL(xScaleChanged(int)), this, SLOT(plotXScaleChanged(int)) );
+	connect( m_plot, SIGNAL(yAutoScaleChanged(bool)), this, SLOT(plotYAutoScaleChanged(bool)) );
 	connect( m_plot, SIGNAL(yMinChanged(float)), this, SLOT(plotYMinChanged(float)) );
 	connect( m_plot, SIGNAL(yMaxChanged(float)), this, SLOT(plotYMaxChanged(float)) );
 	connect( m_plot, SIGNAL(yScaleChanged(int)), this, SLOT(plotYScaleChanged(int)) );
@@ -365,14 +373,12 @@ void CartesianPlotDock::commentChanged(){
   m_plot->setComment(ui.leComment->text());
 }
 
-void CartesianPlotDock::visibilityChanged(int state){
-  if (m_initializing)
-	return;
+void CartesianPlotDock::visibilityChanged(bool state){
+	if (m_initializing)
+		return;
 
-  bool b = (state==Qt::Checked);
-  foreach(CartesianPlot* plot, m_plotList){
-	plot->setVisible(b);
-  }
+	foreach(CartesianPlot* plot, m_plotList)
+		plot->setVisible(state);
 }
 
 void CartesianPlotDock::geometryChanged(){
@@ -683,8 +689,6 @@ void CartesianPlotDock::backgroundColorStyleChanged(int index){
 		ui.lBackgroundFirstColor->setText(i18n("Color"));
 		ui.lBackgroundSecondColor->hide();
 		ui.kcbBackgroundSecondColor->hide();
-		ui.lBackgroundBrushStyle->show();
-		ui.cbBackgroundBrushStyle->show();
 	}else{
 		ui.lBackgroundFirstColor->setText(i18n("First Color"));
 		ui.lBackgroundSecondColor->show();
@@ -745,7 +749,14 @@ void CartesianPlotDock::backgroundSecondColorChanged(const QColor& c){
 void CartesianPlotDock::selectFile() {
 	KConfigGroup conf(KSharedConfig::openConfig(), "CartesianPlotDock");
 	QString dir = conf.readEntry("LastImageDir", "");
-    QString path = QFileDialog::getOpenFileName(this, i18n("Select the image file"), dir);
+
+	QString formats;
+	foreach(const QByteArray format, QImageReader::supportedImageFormats()) {
+		QString f = "*." + QString(format.constData());
+		formats.isEmpty() ? formats+=f : formats+=' '+f;
+	}
+
+	QString path = QFileDialog::getOpenFileName(this, i18n("Select the image file"), dir, i18n("Images (%1)", formats));
     if (path.isEmpty())
         return; //cancel was clicked in the file-dialog
 
@@ -882,6 +893,12 @@ void CartesianPlotDock::plotRectChanged(QRectF& rect){
 	m_initializing = false;
 }
 
+void CartesianPlotDock::plotXAutoScaleChanged(bool value) {
+	m_initializing = true;
+	ui.chkAutoScaleX->setChecked(value);
+	m_initializing = false;
+}
+
 void CartesianPlotDock::plotXMinChanged(float value){
 	m_initializing = true;
 	ui.kleXMin->setText( QString::number(value) );
@@ -900,6 +917,13 @@ void CartesianPlotDock::plotXScaleChanged(int scale){
 	m_initializing = false;
 }
 
+
+void CartesianPlotDock::plotYAutoScaleChanged(bool value) {
+	m_initializing = true;
+	ui.chkAutoScaleY->setChecked(value);
+	m_initializing = false;
+}
+
 void CartesianPlotDock::plotYMinChanged(float value){
 	m_initializing = true;
 	ui.kleYMin->setText( QString::number(value) );
@@ -1159,7 +1183,7 @@ void CartesianPlotDock::loadConfig(KConfig& config){
 	m_initializing=false;
 }
 
-void CartesianPlotDock::saveConfig(KConfig& config){
+void CartesianPlotDock::saveConfigAsTemplate(KConfig& config) {
 // 	KConfigGroup group = config.group( "CartesianPlot" );
 
 	//General-tab
@@ -1209,3 +1233,4 @@ void CartesianPlotDock::saveConfig(KConfig& config){
 
 	config.sync();
 }
+
